# Kingfish
Bunch of scripts

```**DBs:**
mongodb_wizard:
--connect_to_mongodb
--get_collection
--find_documents
--create_document
--insert_to_mongodb

sql_wizard:
--convert_json_to_table
--connect_to_db
--run_query
--insert_row

**Core:**
logger:
--clear_logs_file
--display_logs_file
-@simple logs functions

**Wrapper:**
basic:
--manipulator
--url_extractor

**Special:**
data_class:
-@simple data classes demo
```